# Copyright (C) 2007, 2008, 2009 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Packager that builds KDE-PIM debian packages from the enterprise35 branch.
"""

import os
import time
import re

import treepkg.util
import treepkg.packager

import recipes.kde.enterprise.generic as generic


class SourcePackager(generic.SourcePackager):

    def kdepim_version(self, directory):
        """Determine the kdepim version.

        The version is taken from the kdepim.lsm file.
        """
        return treepkg.util.extract_lsm_version(os.path.join(directory,
                                                             "kdepim.lsm"))

    def determine_package_version(self, directory):
        enterprise_version = self.enterprise_version
        kdepimversion = self.kdepim_version(directory)
        version_template = \
                         "%(kdepimversion)s.enterprise.0.%(enterprise_version)s"
        return version_template % locals()

    def update_version_numbers(self, pkgbasedir):
        """Overrides the inherited method to update version numbers in the code
        """
        versionstring = "(enterprise35 %s)" % self.enterprise_version
        failed = []
        for versionfile in ["kmail/kmversion.h", "kontact/src/main.cpp",
                            "korganizer/version.h"]:
            if not treepkg.util.replace_in_file(os.path.join(pkgbasedir,
                                                             versionfile),
                                                "\(enterprise35 ([^)]*)\)",
                                                versionstring):
                failed.append(versionfile)
        if failed:
            raise RuntimeError("kdepim: failed to update version numbers in %s"
                               % (", ".join(failed),))


class RevisionPackager(generic.RevisionPackager):

    source_packager_cls = SourcePackager


class PackageTrack(generic.PackageTrack):

    revision_packager_cls = RevisionPackager
